@@ -740,8 +740,8 @@ sub configure_block {
     
     unless ( ref $block_list eq 'ARRAY' )
     {
-	$request->{block_field_list} = undef;
-	$request->{block_proc_list} = undef;
+	$request->{block_field_list}{$block_name} = undef;
+	$request->{block_proc_list}{$block_name} = undef;
 	return;
     }
     
@@ -1290,11 +1290,11 @@ sub document_response {
     # string.
     
     return '' unless @blocks;
-			     
+    
     # Otherwise, determine the set of vocabularies that are allowed for this
     # path.  If none are specifically selected for this path, then all of the
     # vocabularies defined for this data service are allowed.
-			     
+    
     my $vocabularies; $vocabularies = $ds->node_attr($path, 'allow_vocab') || $ds->{vocab};	
     
     unless ( ref $vocabularies eq 'HASH' && keys %$vocabularies )
@@ -1366,6 +1366,74 @@ sub document_response {
 }
 
 
+sub document_summary {
+
+    my ($ds, $path) = @_;
+    
+    # Return the empty string unless a summary block was defined for this path.
+    
+    my $summary_block = $ds->node_attr($path, 'summary');
+    return '' unless $summary_block;
+    
+    # Otherwise, determine the set of vocabularies that are allowed for this
+    # path.  If none are specifically selected for this path, then all of the
+    # vocabularies defined for this data service are allowed.
+    
+    my $vocabularies; $vocabularies = $ds->node_attr($path, 'allow_vocab') || $ds->{vocab};	
+    
+    unless ( ref $vocabularies eq 'HASH' && keys %$vocabularies )
+    {
+	return '';
+    }
+    
+    my @vocab_list = grep { $vocabularies->{$_} && 
+			    ref $ds->{vocab}{$_} &&
+			    ! $ds->{vocab}{$_}{disabled} } @{$ds->{vocab_list}};
+    
+    unless ( @vocab_list )
+    {
+	return "";
+    }
+    
+    # Now generate the header for the documentation, in Pod format.  We
+    # include the special "=for wds_table_header" line to give PodParser.pm the
+    # information it needs to generate an HTML table.
+    
+    my $doc_string = '';
+    my $field_count = scalar(@vocab_list);
+    my $field_string = join ' / ', @vocab_list;
+    
+    if ( $field_count > 1 )
+    {
+	$doc_string .= "=for wds_table_header Field name*/$field_count | Block!anchor(block:) | Description\n\n";
+	$doc_string .= "=over 4\n\n";
+	$doc_string .= "=item $field_string\n\n";
+    }
+    
+    else
+    {
+	$doc_string .= "=for wds_table_header Field name* | Block | Description\n\n";
+	$doc_string .= "=over 4\n\n";
+    }
+    
+    # Now determine the summary output list.
+    
+    my $output_list = $ds->{block}{$summary_block}{output_list};
+    return '' unless ref $output_list eq 'ARRAY';
+    
+    foreach my $r (@$output_list)
+    {
+	next unless defined $r->{output};
+	$doc_string .= $ds->document_field('summary', \@vocab_list, $r)
+	    unless $r->{undocumented};
+    }
+    
+    $doc_string .= "\n=back\n\n";
+    
+    return $doc_string;
+}
+
+
 sub document_field {
     
     my ($ds, $block_key, $vocab_list, $r) = @_;
@@ -1571,6 +1639,14 @@ sub process_record {
 	    }
 	}
 	
+	# Otherwise, we just use the vaoue of the source field.
+	
+	else
+	{
+	    @result = ref $record->{$source_field} eq 'ARRAY' ?
+		@{$record->{$source_field}} : $record->{$source_field};
+	}
+	
 	# If the value of 'set' is '*', then we're done.  This is generally
 	# only used to call a procedure with side effects.
 	
@@ -1834,7 +1910,22 @@ sub _generate_compound_result {
     
     $output .= $format_class->emit_footer($request, $field_list);
     
-    return $output;
+    # Determine if we need to encode the output into the proper character set.
+    # Usually Dancer does this for us, but only if it recognizes the content
+    # type as text.  For these formats, the definition should set the
+    # attribute 'encode_as_text' to true.
+    
+    my $output_charset = $ds->{_config}{charset};
+    my $must_encode;
+    
+    if ( $output_charset 
+	 && $ds->{format}{$format}{encode_as_text}
+	 && ! $request->{content_type_is_text} )
+    {
+	$must_encode = 1;
+    }
+    
+    return $must_encode ? encode($output_charset, $output) : $output;
 }
 
     # If the flag 'process_resultset' is set, then we need to fetch and
@@ -1898,14 +1989,30 @@ sub _stream_compound_result {
     
     my $format = $request->output_format;
     my $format_class = $ds->{format}{$format}{package};
+    my $format_is_text = $ds->{format}{$format}{is_text};
     
     croak "could not generate a result in format '$format': no implementing class"
 	unless $format_class;
     
+    # Determine the output character set, because we will need to encode text
+    # responses in it.
+    
+    my $output_charset = $ds->{_config}{charset};
+    
+    #return $must_encode ? encode($output_charset, $output) : $output;
+    
     # First send out the partial output previously stashed by
     # generate_compound_result().
     
-    $writer->write( encode_utf8($ds->{stashed_output}) );
+    if ( $output_charset && $format_is_text )
+    {
+	$writer->write( encode($output_charset, $ds->{stashed_output}) );
+    }
+    
+    else
+    {
+	$writer->write( $ds->{stashed_output} );
+    }
     
     # Then process the remaining rows.
     
@@ -1932,7 +2039,20 @@ sub _stream_compound_result {
 	
 	$output .= $format_class->emit_record($request, $record);
 	
-	$writer->write( encode_utf8($output) ) if defined $output and $output ne '';
+	unless ( defined $output and $output ne '' )
+	{
+	    # do nothing
+	}
+	
+	elsif ( $output_charset && $format_is_text )
+	{
+	    $writer->write( encode($output_charset, $output) );
+	}
+	
+	else
+	{
+	    $writer->write( $output );
+	}
 	
 	# Keep count of the output records, and stop if we have exceeded the
 	# limit. 
