@@ -83,10 +83,10 @@ sub emit_header {
     {
 	my $counts = $request->result_counts;
 	
-	$output .= $class->emit_line($request, "Elapsed Time:", sprintf("%.3g", $request->{elapsed}));
-	$output .= $class->emit_line($request, "Records Found:", $counts->{found});
-	$output .= $class->emit_line($request, "Records Returned:", $counts->{returned});
-	$output .= $class->generate-line($request, "Starting Index:", $counts->{offset})
+	$output .= $class->emit_line($request, "Elapsed Time", sprintf("%.3g", $request->{elapsed}));
+	$output .= $class->emit_line($request, "Records Found", $counts->{found});
+	$output .= $class->emit_line($request, "Records Returned", $counts->{returned});
+	$output .= $class->generate-line($request, "Record Offset", $counts->{offset})
 	    if defined $counts->{offset} && $counts->{offset} > 0;
     }
     
@@ -97,6 +97,16 @@ sub emit_header {
 	$output .= $class->emit_line($request, "Warning:", $_) foreach @msgs;
     }
     
+    # If we have summary data to output, do so now.
+    
+    if ( $request->{summary_data} && $request->{summary_field_list} )
+    {
+	my @summary_fields = map { $_->{name} } @{$request->{summary_field_list}};
+	$output .= $class->emit_line($request, "Summary:");
+	$output .= $class->emit_line($request, @summary_fields);
+	$output .= $class->emit_record($request, $request->{summary_data}, $request->{summary_field_list});
+    }
+    
     # If any header material was generated, add a line to introduce the start
     # of the actual data.
     
@@ -270,7 +280,7 @@ sub csv_clean {
     
     # Next, double all quotes and textify whitespace control characters
     
-    $string =~ s/("|'|\n|\r)/$TXTESCAPE{$1}/ge;
+    $string =~ s/("|\n|\r)/$TXTESCAPE{$1}/ge;
     
     # Finally, delete all other control characters (they shouldn't be in the
     # database in the first place, but unfortunately some rows do contain
